v0.2.0 (2020-01-24)
-------------------
- `--font` now accepts names of builtin fonts
- When an input filename is given but no output filename, write to the input
  filename with the extension set to `.pdf` instead of to stdout
- Eliminated the `--multiline` option and made its behavior the default
- Added a `--sort` option and made `--no-sort` the default behavior
- Support Python 3.8

v0.1.0 (2019-04-15)
-------------------
Initial release
